==> universi-1.0.3-sources.jar: universum/studios/android/universi/UniversiFragmentDelegate.java <==
/*
 * =================================================================================================
 *                             Copyright (C) 2017 Universum Studios
 * =================================================================================================
 *         Licensed under the Apache License, Version 2.0 or later (further "License" only).
 * -------------------------------------------------------------------------------------------------
 * You may use this file only in compliance with the License. More details and copy of this License 
 * you may obtain at
 * 
 * 		http://www.apache.org/licenses/LICENSE-2.0
 * 
 * You can redistribute, modify or publish any part of the code written within this file but as it 
 * is described in the License, the software distributed under the License is distributed on an 
 * "AS IS" BASIS, WITHOUT WARRANTIES or CONDITIONS OF ANY KIND.
 * 
 * See the License for the specific language governing permissions and limitations under the License.
 * =================================================================================================
 */
package universum.studios.android.universi;

import android.content.Context;
import android.support.annotation.NonNull;
import android.app.Fragment;

import universum.studios.android.dialog.manage.DialogController;

/**
 * An {@link UniversiContextDelegate} implementation that can be used within context of {@link Fragment}.
 *
 * @author Martin Albedinsky
 * @see UniversiActivityDelegate
 */
final class UniversiFragmentDelegate extends UniversiContextDelegate {

	/*
	 * Constants ===================================================================================
	 */

	/**
	 * Log TAG.
	 */
	// private static final String TAG = "UniversiFragmentDelegate";

	/*
	 * Interface ===================================================================================
	 */

	/*
	 * Static members ==============================================================================
	 */

	/*
	 * Members =====================================================================================
	 */

	/**
	 * Fragment instance for which has been this delegate created.
	 */
	private final Fragment mFragment;

	/*
	 * Constructors ================================================================================
	 */

	/**
	 * Creates a new instance of UniversiFragmentDelegate for the given fragment <var>context</var>.
	 *
	 * @see UniversiContextDelegate#UniversiContextDelegate(Context)
	 */
	UniversiFragmentDelegate(@NonNull final Fragment context) {
		super(context.getActivity());
		this.mFragment = context;
	}

	/*
	 * Methods =====================================================================================
	 */

	/**
	 */
	@NonNull
	@Override
	DialogController instantiateDialogController() {
		return new DialogController(mFragment);
	}

	/*
	 * Inner classes ===============================================================================
	 */
}

==> universi-1.0.4-sources.jar: universum/studios/android/universi/UniversiFragmentDelegate.java <==
/*
 * =================================================================================================
 *                             Copyright (C) 2017 Universum Studios
 * =================================================================================================
 *         Licensed under the Apache License, Version 2.0 or later (further "License" only).
 * -------------------------------------------------------------------------------------------------
 * You may use this file only in compliance with the License. More details and copy of this License 
 * you may obtain at
 * 
 * 		http://www.apache.org/licenses/LICENSE-2.0
 * 
 * You can redistribute, modify or publish any part of the code written within this file but as it 
 * is described in the License, the software distributed under the License is distributed on an 
 * "AS IS" BASIS, WITHOUT WARRANTIES or CONDITIONS OF ANY KIND.
 * 
 * See the License for the specific language governing permissions and limitations under the License.
 * =================================================================================================
 */
package universum.studios.android.universi;

import android.content.Context;
import android.support.annotation.NonNull;
import android.app.Fragment;
import android.support.annotation.VisibleForTesting;

import universum.studios.android.dialog.manage.DialogController;

/**
 * An {@link UniversiContextDelegate} implementation that can be used within context of {@link Fragment}.
 *
 * @author Martin Albedinsky
 * @see UniversiActivityDelegate
 */
public class UniversiFragmentDelegate extends UniversiContextDelegate {

	/*
	 * Constants ===================================================================================
	 */

	/**
	 * Log TAG.
	 */
	// private static final String TAG = "UniversiFragmentDelegate";

	/*
	 * Interface ===================================================================================
	 */

	/*
	 * Static members ==============================================================================
	 */

	/*
	 * Members =====================================================================================
	 */

	/**
	 * Fragment instance for which has been this delegate created.
	 */
	private final Fragment mFragment;

	/*
	 * Constructors ================================================================================
	 */

	/**
	 * Creates a new instance of UniversiFragmentDelegate for the given fragment <var>context</var>.
	 *
	 * @see UniversiContextDelegate#UniversiContextDelegate(Context)
	 */
	@VisibleForTesting
	UniversiFragmentDelegate(@NonNull final Fragment context) {
		super(context.getActivity());
		this.mFragment = context;
	}

	/*
	 * Methods =====================================================================================
	 */

	/**
	 * Creates a new instance of UniversiFragmentDelegate for the given <var>fragment</var>.
	 *
	 * @param fragment The fragment context in which will be the new delegate used.
	 * @return Ready to be used delegate.
	 */
	@NonNull
	public static UniversiFragmentDelegate create(@NonNull final Fragment fragment) {
		return new UniversiFragmentDelegate(fragment);
	}

	/**
	 */
	@NonNull
	@Override
	DialogController instantiateDialogController() {
		return new DialogController(mFragment);
	}

	/*
	 * Inner classes ===============================================================================
	 */
}
